# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="$(dirname $NEW)/$(basename $NEW .new)"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

config etc/default/domoticz.new
config etc/logrotate.d/domoticz.new
preserve_perms etc/rc.d/rc.domoticz.new

# Only way to create and use the correct uid and gid on the target system,
# is to use chroot:
chroot . <<EOR 2>/dev/null
# Add the '371' group if it doesn't exist already:
/usr/sbin/groupadd -g 371 domoticz 2> /dev/null

# Add the '371' user if it doesn't exist already:
/usr/sbin/useradd -c "Domoticz home automation" -d /opt/domoticz -M \
  -s "/bin/false" -g 371 -u 371 domoticz 2> /dev/null
EOR

# Update rc.local so that Domoticz daemon will be started on boot
if ! grep "rc.domoticz" etc/rc.d/rc.local 1>/dev/null 2>&1 ; then
  cat <<_EOM_ >> etc/rc.d/rc.local

if [ -x /etc/rc.d/rc.domoticz ]; then
  # Start Domoticz daemon
  echo "Starting Domoticz daemon:    /etc/rc.d/rc.domoticz start"
  /etc/rc.d/rc.domoticz start
fi
_EOM_
fi

# Update rc.local_shutdown so that Domoticz daemon will be stopped properly:
if ! grep "rc.domoticz" etc/rc.d/rc.local_shutdown 1>/dev/null 2>&1 ; then
  cat <<_EOS_ >> etc/rc.d/rc.local_shutdown

if [ -x /etc/rc.d/rc.domoticz ]; then
  # Stop Domoticz daemon
  echo "Stopping Domoticz daemon:    /etc/rc.d/rc.domoticz stop"
  /etc/rc.d/rc.domoticz stop
fi
_EOS_
fi

